@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -30,17 +30,17 @@ extern "C" {
 #define MagickLibVersion  0x69C
 #define MagickLibVersionText  "6.9.12"
 #define MagickLibVersionNumber  7,0,0
-#define MagickLibAddendum  "-76"
+#define MagickLibAddendum  "-88"
 #define MagickLibInterface  7
 #define MagickLibMinInterface  7
-#define MagickPlatform  "i386"
+#define MagickPlatform  "aarch64"
 #define MagickppLibVersionText  "6.9.12"
 #define MagickppLibVersionNumber  9:0:0
-#define MagickppLibAddendum  "-76"
+#define MagickppLibAddendum  "-88"
 #define MagickppLibInterface  9
 #define MagickppLibMinInterface  9
-#define MagickGitRevision  "17694"
-#define MagickReleaseDate  "2023-02-05"
+#define MagickGitRevision  "17833"
+#define MagickReleaseDate  "2023-05-21"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
